summaryrefslogtreecommitdiffstats
path: root/kdecore/ksycoca.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdecore/ksycoca.cpp')
-rw-r--r--kdecore/ksycoca.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdecore/ksycoca.cpp b/kdecore/ksycoca.cpp
index 2df7ae772..3a655d617 100644
--- a/kdecore/ksycoca.cpp
+++ b/kdecore/ksycoca.cpp
@@ -98,7 +98,7 @@ KSycoca::KSycoca()
}
// We register with DCOP _before_ we try to open the database.
// This way we can be relative sure that the KDE framework is
// up and running (kdeinit, dcopserver, klaucnher, kded) and
// that the database is up to date.
openDatabase();
_self = this;
@@ -332,7 +332,7 @@ TQDataStream * KSycoca::findFactory(KSycocaFactoryId id)
if (!triedLaunchingKdeinit) // try only once
{
triedLaunchingKdeinit = true;
- kdDebug(7011) << "findFactory: we have no database.... launching kdeinit" << endl;
+ kdDebug(7011) << "findFactory: we have no database.... launching tdeinit" << endl;
KApplication::startKdeinit();
// Ok, the new database should be here now, open it.
}
@@ -98,7 +98,7 @@ KSycoca::KSycoca()
// We register with DCOP _before_ we try to open the database.
// This way we can be relative sure that the KDE framework is
- // up and running (kdeinit, dcopserver, klaucnher, kded) and
+ // up and running (tdeinit, dcopserver, klaucnher, kded) and
// that the database is up to date.
openDatabase();